pub struct CachedMatches { /* private fields */ }Expand description
Cached search results from fuzzy search.
Maps (pattern_index, start_position) -> Vec<FuzzyMatchResult>
Implementations
Sourceimpl CachedMatches
impl CachedMatches
Sourcepub fn get(
&self,
pattern_index: usize,
start: usize,
) -> Option<&FuzzyMatchResult>
pub fn get( &self, pattern_index: usize, start: usize, ) -> Option<&FuzzyMatchResult>
Get the best match for a pattern at a specific start position.
Sourcepub fn get_all(
&self,
pattern_index: usize,
start: usize,
) -> Option<&[FuzzyMatchResult]>
pub fn get_all( &self, pattern_index: usize, start: usize, ) -> Option<&[FuzzyMatchResult]>
Get all matches for a pattern at a specific start position.
Sourcepub fn insert(
&mut self,
pattern_index: usize,
start: usize,
result: FuzzyMatchResult,
)
pub fn insert( &mut self, pattern_index: usize, start: usize, result: FuzzyMatchResult, )
Insert a match result for a pattern at a specific start position.