pub struct LiteralPattern {
pub text: String,
pub limits: Option<FuzzyLimits>,
pub min_edits: Option<u8>,
pub edit_chars: Option<EditCharRestriction>,
}Expand description
A literal pattern extracted from the HIR for fuzzy matching.
Fields
text: StringThe literal text.
limits: Option<FuzzyLimits>Fuzzy limits for this pattern.
min_edits: Option<u8>Minimum edits required (for exclusive lower bounds like {0<e<5}).
edit_chars: Option<EditCharRestriction>Character class restriction for edits. If set, all edit characters must be from this class.
Implementations
Sourceimpl LiteralPattern
impl LiteralPattern
Sourcepub fn new(
text: String,
limits: Option<FuzzyLimits>,
min_edits: Option<u8>,
) -> Self
pub fn new( text: String, limits: Option<FuzzyLimits>, min_edits: Option<u8>, ) -> Self
Create a new literal pattern.
Sourcepub fn with_edit_chars(
text: String,
limits: Option<FuzzyLimits>,
min_edits: Option<u8>,
edit_chars: Option<EditCharRestriction>,
) -> Self
pub fn with_edit_chars( text: String, limits: Option<FuzzyLimits>, min_edits: Option<u8>, edit_chars: Option<EditCharRestriction>, ) -> Self
Create a new literal pattern with character class restriction.