pub struct CharClass {
pub negated: bool,
pub items: Vec<CharClassItem>,
}Expand description
Character class definition.
Fields
negated: boolWhether this is a negated class [^...].
items: Vec<CharClassItem>The ranges/characters in this class.
Implementations
Sourceimpl CharClass
impl CharClass
Sourcepub fn new(negated: bool, items: Vec<CharClassItem>) -> Self
pub fn new(negated: bool, items: Vec<CharClassItem>) -> Self
Create a new character class.
Sourcepub fn any() -> Self
pub fn any() -> Self
Create a character class matching any character except newlines (default .).
Sourcepub fn any_with_newlines() -> Self
pub fn any_with_newlines() -> Self
Create a character class matching any character including newlines (dot_all .).
Sourcepub fn whitespace() -> Self
pub fn whitespace() -> Self
Create a whitespace class (\s).
Sourcepub fn matches_unicode(&self, ch: char) -> bool
pub fn matches_unicode(&self, ch: char) -> bool
Check if a character matches this class with Unicode support.