MatchFlags

Struct MatchFlags 

pub struct MatchFlags {
    pub best_match: bool,
    pub enhance_match: bool,
    pub posix: bool,
    pub verbose: bool,
    pub dot_all: bool,
    pub multi_line: bool,
    pub ungreedy: bool,
    pub case_insensitive: bool,
    pub global: bool,
    pub unicode: bool,
}
Matching flags that can be set in the pattern.

Fields

best_match: bool

BESTMATCH flag ((?b)) - search for the best match instead of the first.

enhance_match: bool

ENHANCEMATCH flag ((?e)) - improve the fit of fuzzy matches.

posix: bool

POSIX leftmost-longest flag ((?p)) - find longest match at leftmost position.

verbose: bool

Verbose flag ((?x)) - ignore whitespace and allow comments.

dot_all: bool

Dot-all flag ((?s)) - . matches newlines.

multi_line: bool

Multi-line flag ((?m)) - ^/$ match at line boundaries.

ungreedy: bool

Ungreedy flag ((?U)) - invert default greediness of quantifiers.

case_insensitive: bool

Case-insensitive flag ((?i)) - match case-insensitively.

global: bool

Global flag ((?g)) - find all matches, not just the first.

unicode: bool

Unicode flag ((?u)) - enable Unicode character classes.

Implementations

Source

impl MatchFlags

pub fn new() -> Self

Create a new empty flags set.

pub fn with_best_match(self) -> Self

Set the BESTMATCH flag.

pub fn with_enhance_match(self) -> Self

Set the ENHANCEMATCH flag.

pub fn with_posix(self) -> Self

Set the POSIX flag.