pub struct Lexer<'a> { /* private fields */ }Expand description
Lexer for regex patterns.
Implementations
Sourceimpl<'a> Lexer<'a>
impl<'a> Lexer<'a>
Sourcepub fn new_with_flags(input: &'a str, verbose: bool) -> Self
pub fn new_with_flags(input: &'a str, verbose: bool) -> Self
Create a new lexer with verbose mode.
Sourcepub fn set_position(&mut self, pos: usize)
pub fn set_position(&mut self, pos: usize)
Set the position in the input (for backtracking).
Sourcepub fn try_match(&mut self, s: &str) -> bool
pub fn try_match(&mut self, s: &str) -> bool
Try to match a specific string, advancing if successful.
This is useful for parser extensions that need to match multi-character sequences like keywords or specific syntax.
Sourcepub fn next_token(&mut self) -> Result<Token>
pub fn next_token(&mut self) -> Result<Token>
Sourcepub fn peek_token(&mut self) -> Result<Token>
pub fn peek_token(&mut self) -> Result<Token>
Peek at the next token without consuming it.
Errors
Returns an error if an invalid escape sequence is encountered.