FuzzyLimits

Struct FuzzyLimits 

pub struct FuzzyLimits { /* private fields */ }
Limits on the number of edit operations allowed during fuzzy matching.

Edit operations include:

  • Insertions: Extra characters in the text that aren’t in the pattern
  • Deletions: Characters in the pattern that are missing from the text
  • Substitutions: Characters that differ between pattern and text
  • Swaps: Adjacent character transpositions

You can set a total edit limit with edits(), or individual limits for each operation type. When individual limits are set without a total, the total is computed as the sum of individual limits.

Implementations

Source

impl FuzzyLimits

pub fn new() -> Self

Create new empty fuzzy limits (exact match only).

pub fn insertions(self, num: NumEdits) -> Self

Set the maximum number of insertions allowed.

pub fn deletions(self, num: NumEdits) -> Self

Set the maximum number of deletions allowed.

pub fn substitutions(self, num: NumEdits) -> Self

Set the maximum number of substitutions allowed.

pub fn swaps(self, num: NumEdits) -> Self

Set the maximum number of swaps (transpositions) allowed.

pub fn edits(self, num: NumEdits) -> Self

Set the maximum total number of edits allowed.

pub fn get_edits(&self) -> Option<NumEdits>

Get the maximum total edits allowed.

pub fn get_insertions(&self) -> Option<NumEdits>

Get the maximum insertions allowed.

pub fn get_deletions(&self) -> Option<NumEdits>

Get the maximum deletions allowed.

pub fn get_substitutions(&self) -> Option<NumEdits>

Get the maximum substitutions allowed.

pub fn get_swaps(&self) -> Option<NumEdits>

Get the maximum swaps allowed.