pub struct MatchFlags {
pub best_match: bool,
pub enhance_match: bool,
pub posix: bool,
pub verbose: bool,
pub dot_all: bool,
pub multi_line: bool,
pub ungreedy: bool,
pub case_insensitive: bool,
pub global: bool,
pub unicode: bool,
}Expand description
Matching flags that can be set in the pattern.
Fields
best_match: boolBESTMATCH flag ((?b)) - search for the best match instead of the first.
enhance_match: boolENHANCEMATCH flag ((?e)) - improve the fit of fuzzy matches.
posix: boolPOSIX leftmost-longest flag ((?p)) - find longest match at leftmost position.
verbose: boolVerbose flag ((?x)) - ignore whitespace and allow comments.
dot_all: boolDot-all flag ((?s)) - . matches newlines.
multi_line: boolMulti-line flag ((?m)) - ^/$ match at line boundaries.
ungreedy: boolUngreedy flag ((?U)) - invert default greediness of quantifiers.
case_insensitive: boolCase-insensitive flag ((?i)) - match case-insensitively.
global: boolGlobal flag ((?g)) - find all matches, not just the first.
unicode: boolUnicode flag ((?u)) - enable Unicode character classes.
Implementations
Sourceimpl MatchFlags
impl MatchFlags
Sourcepub fn with_best_match(self) -> Self
pub fn with_best_match(self) -> Self
Set the BESTMATCH flag.
Sourcepub fn with_enhance_match(self) -> Self
pub fn with_enhance_match(self) -> Self
Set the ENHANCEMATCH flag.
Sourcepub fn with_posix(self) -> Self
pub fn with_posix(self) -> Self
Set the POSIX flag.